﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;

[CustomEditor(typeof(Evidence)), CanEditMultipleObjects]
public class EvidenceEditor : Editor {

    public SerializedProperty
        type_prop,
        details_prop,
        id_prop,
        timestamp_prop,
        roomFound_prop,
        location_prop,
        size_prop,
        witness_prop,
        e1_id_prop,
        e2_id_prop;

    void OnEnable()
    {
        type_prop      = serializedObject.FindProperty("type");
        details_prop   = serializedObject.FindProperty("details");
        id_prop        = serializedObject.FindProperty("id");
        timestamp_prop = serializedObject.FindProperty("timestamp");
        roomFound_prop = serializedObject.FindProperty("roomFound");
        location_prop  = serializedObject.FindProperty("location");
        size_prop      = serializedObject.FindProperty("size");
        witness_prop   = serializedObject.FindProperty("witness");
        e1_id_prop     = serializedObject.FindProperty("e1_id");
        e2_id_prop     = serializedObject.FindProperty("e2_id");
    }


    //Clears the editor of editable fields;
    public override void OnInspectorGUI()
    {
        serializedObject.Update();

        EditorGUILayout.PropertyField(id_prop, new GUIContent("Evidence ID"));
        EditorGUILayout.PropertyField(type_prop, new GUIContent("Type"));
        EditorGUILayout.PropertyField(details_prop, new GUIContent("Details"));


        Evidence.evidenceType st = (Evidence.evidenceType)type_prop.enumValueIndex;

        switch(st)
        {
            case Evidence.evidenceType.Clue:
                EditorGUILayout.PropertyField(timestamp_prop, new GUIContent("Timestamp"));
                EditorGUILayout.PropertyField(roomFound_prop, new GUIContent("Found in Room"));
                EditorGUILayout.PropertyField(location_prop, new GUIContent("Exact Location"));
                EditorGUILayout.PropertyField(size_prop, new GUIContent("Width, Height"));
                break;

            case Evidence.evidenceType.Statement:
                EditorGUILayout.PropertyField(witness_prop, new GUIContent("Witness"));
                break;

            case Evidence.evidenceType.Corroboration:
                EditorGUILayout.PropertyField(e1_id_prop, new GUIContent("Evidence 1"));
                EditorGUILayout.PropertyField(e2_id_prop, new GUIContent("Evidence 2"));
                break;
            case Evidence.evidenceType.NullEvidence:
                break;
        }

        serializedObject.ApplyModifiedProperties();
    }


}
