﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class MovementEvent : MonoBehaviour {
	/// <summary>
	/// Moves a specified character to an end location. All information is passed in through the CutsceneEvent struct.
	/// </summary>
	/// <returns>Nothing</returns>
	/// <param name="cutsceneEvent">the CutsceneEvent that you want to use</param>
	public IEnumerator movementAction(CutsceneEvent cutsceneEvent) {
		GameObject movingCharacter = null;
		Rigidbody characterRigidbody = null;
        DetectiveScript detectiveScript = null;
        movingCharacter = cutsceneEvent.character;
		//checks to make sure a character was actually attached to the movingCharacter game object. If not, it passes in an error
		if (movingCharacter == null) {
			Debug.LogError ("no character exists in this scene with name " + cutsceneEvent.charName);
		}
		//attaches the character's rigidbody. If there is no Rigidbody2D on the character, pass in an error
		characterRigidbody = movingCharacter.GetComponent<Rigidbody>();
		if (characterRigidbody == null) {
			Debug.LogError ("no Rigidbody2D on the " + cutsceneEvent.charName + " character");
		}
        //sets the velocity of the character to a normalized direction vector, with a magnitude of the speed passed in through the CutsceneEvent
        //characterRigidbody.velocity = (cutsceneEvent.endLocation - new Vector3(movingCharacter.transform.position.x, 0,  movingCharacter.transform.position.y)).normalized * cutsceneEvent.speed;
        detectiveScript = movingCharacter.GetComponent<DetectiveScript>();
        if(detectiveScript == null)
        {
            Debug.LogError("no detective script on " + cutsceneEvent.character.name + ".");
        }
        detectiveScript.MoveToLocation(cutsceneEvent.endLocation);
        //checks if the cutscene has to wait for this action to complete
        if (cutsceneEvent.wait) {
			//if yes, start a new coroutine and make this coroutine wait for that coroutine to complete
			yield return StartCoroutine (completeMovementAction (movingCharacter, cutsceneEvent.endLocation, characterRigidbody));
		} else {
			//if no, start a new coroutine and let this coroutine continue on as normal
			StartCoroutine (completeMovementAction (movingCharacter, cutsceneEvent.endLocation, characterRigidbody));
		}
		//end this coroutine
		yield return 0;
	}

	public IEnumerator completeMovementAction(GameObject character, Vector3 endPosition, Rigidbody characterRigidbody) {
		bool completed = false;
		//while the character has still not reached the end of its movemnet
		while (!completed) {
			//check if the character has reached the end of its movement
			if (character.transform.position.x >= endPosition.x - 0.5 && character.transform.position.x <= endPosition.x + 0.5) {
				if (character.transform.position.y >= endPosition.y - 0.5 && character.transform.position.y <= endPosition.y + 0.5) {
                    if (character.transform.position.z >= endPosition.z - 1 && character.transform.position.z <= endPosition.z + 1) {
                        //signal to the while loop that it has completed its process
                        completed = true;
                    }
				}
			}
			yield return new WaitForEndOfFrame ();
		}
		//stop the character from moving
		characterRigidbody.velocity = Vector3.zero;
		yield return 0;
	}
}

